"""Top-level package for Python Casim."""

__author__ = """Sergeileduc"""
__email__ = 'sergei.leduc@gmail.com'
__version__ = '2.0.0'

from .casim import Casim, CasimLogged

__all__ = ["Casim", "CasimLogged"]
